@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@ import jax.numpy as jnp
 norm = jnp.linalg.norm
 
 
-from cr.sparse import norms_l2_cw
+from cr.nimble import norms_l2_cw
 
 def project_to_ball(x, radius=1.0):
     """Projects a vector to the :math:`\\ell_2` ball of a specified radius.
