@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import math
 from typing import NamedTuple, List, Dict
 from dataclasses import dataclass
 import jax.numpy as jnp
 from jax.tree_util import register_pytree_node
+from cr.nimble.dsp import build_signal_from_indices_and_values
+norm = jnp.linalg.norm
 
 @dataclass
 class SingleRecoverySolution:
@@ -73,6 +76,28 @@ class RecoverySolution(NamedTuple):
     iterations: int
     """The number of iterations it took to complete"""
 
+    length: int
+    """The length of the sparse signal"""
+
+    @property
+    def x(self):
+        return build_signal_from_indices_and_values(self.length, self.I, self.x_I)
+
+    def __str__(self):
+        """Returns the string representation of the discrete wavelet object
+        """
+        s = []
+        r_norm = math.sqrt(float(self.r_norm_sqr))
+        x_norm = float(norm(self.x_I))
+        for x in [
+            u"iterations %s" % self.iterations,
+            f"m={len(self.r)}, n={self.length}, k={len(self.I)}",
+            u"r_norm %e" % r_norm,
+            u"x_norm %e" % x_norm,
+            ]:
+            s.append(x.rstrip())
+        return u'\n'.join(s)
+
 
 class PTConfig(NamedTuple):
     K: int
@@ -106,6 +131,21 @@ class HTPState(NamedTuple):
     x_I_prev: jnp.ndarray
     r_norm_sqr_prev: jnp.ndarray
 
+    def __str__(self):
+        """Returns the string representation of the discrete wavelet object
+        """
+        s = []
+        for x in [
+            u"iterations %s" % self.iterations,
+            u"r_norm_sqr %e" % self.r_norm_sqr,
+            # u"r_norm_sqr_prev %e" % self.r_norm_sqr_prev,
+            # u"I %s" % self.I,
+            # u"I_prev %s" % self.I_prev,
+            ]:
+            s.append(x.rstrip())
+        return u'\n'.join(s)
+
+
 IHTState = HTPState
 
 CoSaMPState = HTPState
\ No newline at end of file
