@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,8 @@ from jax import vmap, jit, lax
 
 from .defs import RecoverySolution, IHTState
 
-from cr.sparse import hard_threshold, build_signal_from_indices_and_values
+from cr.nimble.dsp import (
+    hard_threshold, build_signal_from_indices_and_values)
 import cr.sparse.dict as crdict
 import cr.sparse.lop as lop
 
@@ -111,7 +112,7 @@ def matrix_solve(Phi, y, K, normalized=False, step_size=None, max_iters=None, re
 
     state = lax.while_loop(cond, body, init())
     return RecoverySolution(x_I=state.x_I, I=state.I, r=state.r, r_norm_sqr=state.r_norm_sqr,
-        iterations=state.iterations)
+        iterations=state.iterations, length=Phi.shape[1])
 
 
 matrix_solve_jit = jit(matrix_solve, static_argnums=(2), 
@@ -206,7 +207,7 @@ def operator_solve(Phi, y, K, normalized=False, step_size=None, max_iters=None,
 
     state = lax.while_loop(cond, body, init())
     return RecoverySolution(x_I=state.x_I, I=state.I, r=state.r, r_norm_sqr=state.r_norm_sqr,
-        iterations=state.iterations)
+        iterations=state.iterations, length=Phi.shape[1])
 
 
 operator_solve_jit = jit(operator_solve, static_argnums=(0, 2), 
