@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,10 +14,9 @@
 
 
 import jax.numpy as jnp
-from jax.ops import index, index_add
 from jax.numpy.linalg import norm
 from .defs import SingleRecoverySolution
-from cr.sparse import *
+import cr.nimble as cnb
 
 def solve_smv(dictionary, x, max_iters=None, max_res_norm=None):
     # initialize residual
@@ -47,7 +46,7 @@ def solve_smv(dictionary, x, max_iters=None, max_res_norm=None):
         # pick corresponding correlation value
         coeff = correlations[best_match_index]
         # update the representation
-        z  = index_add(z, index[best_match_index], coeff)
+        z  = z.at[best_match_index].add(coeff)
         # find the best match atom
         atom = dictionary[best_match_index]
         # update the residual
@@ -80,7 +79,7 @@ def solve_mmv(dictionary, signals, max_iters=None, max_res_norm=None):
     # iteration count
     t = 0
     # compute the norm of original signal
-    x_norms = norms_l2_rw(signals)
+    x_norms = cnb.norms_l2_rw(signals)
     # absolute limit on res norm
     upper_res_norm = jnp.max(x_norms) * 1e-6
     # upper limit on number of iterations
@@ -100,15 +99,16 @@ def solve_mmv(dictionary, signals, max_iters=None, max_res_norm=None):
             # pick corresponding correlation value
             coeff = correlations[best_match_index, i]
             # update the representation
-            z  = index_add(z, index[i, best_match_index], coeff)
+            z  = z.at[i, best_match_index].add(coeff)
+
             # find the best match atom
             atom = dictionary[best_match_index]
             # update the residual
             update = coeff * atom
-            residuals = index_add(residuals, index[i, :], -update)
+            residuals = residuals.at[i, :].add(-update)
         t += 1
         # compute the updated residual norm
-        r_norms = norms_l2_rw(residuals)
+        r_norms = cnb.norms_l2_rw(residuals)
         max_r_norm = jnp.max(r_norms)
         # print("[{}] norm: {}".format(t, r_norm))
         print('.', end="", flush=True)
