@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@ import jax.numpy as jnp
 from jax import vmap, jit, lax
 
 from .util import abs_max_idx, gram_chol_update
-from cr.sparse.la import solve_spd_chol
+from cr.nimble import solve_spd_chol
 from .defs import RecoverySolution
 
 def matrix_solve(Phi, y, max_iters, max_res_norm=1e-6):
@@ -80,7 +80,7 @@ def matrix_solve(Phi, y, max_iters, max_res_norm=1e-6):
         r = y - Phi_I @ x_I
         # norm squared of new residual
         norm_r_new_sqr = r.T @ r
-    return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=norm_r_new_sqr, iterations=k+1)
+    return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=norm_r_new_sqr, iterations=k+1, length=Phi.shape[1])
 
 
 
