@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ from jax import vmap, jit, lax
 
 from .defs import RecoverySolution
 
-from cr.sparse import largest_indices
+from cr.nimble.dsp import largest_indices
 
 
 
@@ -50,7 +50,7 @@ def matrix_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
         # Compute residual norm squared
         r_norm_sqr = r.T @ r
         # Assemble the algorithm state at the end of first iteration
-        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=1)
+        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=1, length=Phi.shape[1])
 
     def body(state):
         # compute the correlations of dictionary atoms with the residual
@@ -80,7 +80,7 @@ def matrix_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
         r = y - Phi_I @ x_I
         # Compute residual norm squared
         r_norm_sqr = r.T @ r
-        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=state.iterations+1)
+        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=state.iterations+1, length=Phi.shape[1])
 
     def cond(state):
         # limit on residual norm 
@@ -93,7 +93,7 @@ def matrix_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
     state = lax.while_loop(cond, body, init())
     return state
 
-matrix_solve_jit = jit(matrix_solve, static_argnums=(2), static_argnames=("step_size", "max_iters", "res_norm_rtol"))
+matrix_solve_jit = jit(matrix_solve, static_argnums=(2), static_argnames=("max_iters", "res_norm_rtol"))
 
 
 def operator_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
@@ -124,7 +124,7 @@ def operator_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
         # Compute residual norm squared
         r_norm_sqr = r.T @ r
         # Assemble the algorithm state at the end of first iteration
-        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=1)
+        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=1, length=Phi.shape[1])
 
     def body(state):
         # compute the correlations of dictionary atoms with the residual
@@ -154,7 +154,7 @@ def operator_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
         r = y - Phi_I @ x_I
         # Compute residual norm squared
         r_norm_sqr = r.T @ r
-        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=state.iterations+1)
+        return RecoverySolution(x_I=x_I, I=I, r=r, r_norm_sqr=r_norm_sqr, iterations=state.iterations+1, length=Phi.shape[1])
 
     def cond(state):
         # limit on residual norm 
@@ -167,6 +167,6 @@ def operator_solve(Phi, y, K, max_iters=None, res_norm_rtol=1e-4):
     state = lax.while_loop(cond, body, init())
     return state
 
-operator_solve_jit = jit(operator_solve, static_argnums=(0, 2), static_argnames=("step_size", "max_iters", "res_norm_rtol"))
+operator_solve_jit = jit(operator_solve, static_argnums=(0, 2), static_argnames=("max_iters", "res_norm_rtol"))
 
 solve = operator_solve_jit
