@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,8 @@ from cr.sparse._src.data.synthetic.random import (
     sparse_normal_representations,
     sparse_biuniform_representations,
     sparse_spikes,
-    index_sets
+    index_sets,
+    points_orthogonal_to
 )
 
 from cr.sparse._src.data.synthetic.subspaces import (
@@ -34,4 +35,9 @@ from cr.sparse._src.data.synthetic.subspaces import (
     two_subspaces_at_angle_jit,
     three_subspaces_at_angle,
     three_subspaces_at_angle_jit
-)
\ No newline at end of file
+)
+
+# Block sparsity
+from cr.sparse._src.data.synthetic.random import (
+    sparse_normal_blocks
+)
