@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -62,6 +62,7 @@ spread_with_table
 from cr.sparse._src.lop.basic import (
     real_matrix,
     matrix,
+    sparse_real_matrix,
     scalar_mult,
     diagonal,
     zero,
@@ -144,6 +145,7 @@ from cr.sparse._src.lop.special_matrices import (
 from cr.sparse._src.lop.random import (
     gaussian_dict,
     rademacher_dict,
+    sparse_binary_dict,
     random_onb_dict,
     random_orthonormal_rows_dict,
 )
@@ -155,3 +157,9 @@ from cr.sparse._src.lop.normest import (
     normest,
     normest_jit
 )
+
+
+# Undocumented
+from cr.sparse._src.lop.random import (
+    binary_dict_alg,
+)
\ No newline at end of file
