@@ -1,4 +1,4 @@
-# Copyright 2021 CR.Sparse Development Team
+# Copyright 2021 CR-Suite Development Team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,4 +26,14 @@ from cr.sparse._src.opt.projections import (
 
 from cr.sparse._src.opt.shrinkage import (
     shrink
+)
+
+
+from .indicators import *
+from .projectors import *
+from .proximal_ops import *
+from .smooth import *
+
+from cr.sparse._src.opt.prox_to_smooth import (
+    moreau_envelope
 )
\ No newline at end of file
